#ifndef _XENO_ASM_GENERIC_PCI_IDS_H
#define _XENO_ASM_GENERIC_PCI_IDS_H

#include <linux/pci_ids.h>

/* SMI */
#ifndef PCI_DEVICE_ID_INTEL_82801EB_0
#define PCI_DEVICE_ID_INTEL_82801EB_0 0x24d0
#endif
#ifndef PCI_DEVICE_ID_INTEL_ESB2_0
#define PCI_DEVICE_ID_INTEL_ESB2_0 0x2670
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH7_0
#define PCI_DEVICE_ID_INTEL_ICH7_0 0x27b8
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH7_1
#define PCI_DEVICE_ID_INTEL_ICH7_1 0x27b9
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH8_4
#define PCI_DEVICE_ID_INTEL_ICH8_4 0x2815
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH9_1
#define PCI_DEVICE_ID_INTEL_ICH9_1 0x2917
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH9_5
#define PCI_DEVICE_ID_INTEL_ICH9_5 0x2919
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH10_1
#define PCI_DEVICE_ID_INTEL_ICH10_1 0x3a16
#endif
#ifndef PCI_DEVICE_ID_INTEL_PCH_LPC_MIN
#define PCI_DEVICE_ID_INTEL_PCH_LPC_MIN 0x3b00
#endif

/* RTCAN */
#ifndef PCI_VENDOR_ID_ESDGMBH
#define PCI_VENDOR_ID_ESDGMBH 0x12fe
#endif
#ifndef PCI_DEVICE_ID_PLX_9030
#define PCI_DEVICE_ID_PLX_9030 0x9030
#endif
#ifndef PCI_DEVICE_ID_PLX_9056
#define PCI_DEVICE_ID_PLX_9056 0x9056
#endif

#endif /* _XENO_ASM_GENERIC_PCI_IDS_H */
